/*\file SpcNodes.c
 *\brief: build degrees of freedom for every node.
 */

#include "./SpcNodes.h"


void mexFunction( int nlhs, mxArray* plhs[], int nrhs, const mxArray* prhs[]){

	/*diverse: */
	int   noerr=1;

	/*input datasets: */
	Nodes* nodes=NULL;
	Constraints* constraints=NULL;
	int      analysis_type;

	/* output datasets: */
	Vec         yg=NULL;

	/*Boot module: */
	MODULEBOOT();

	/*checks on arguments on the matlab side: */
	CheckNumMatlabArguments(nlhs,NLHS,nrhs,NRHS,__FUNCT__,&SpcNodesUsage);

	/*Input datasets: */
	FetchData((DataSet**)&nodes,NODESIN);
	FetchData((DataSet**)&constraints,CONSTRAINTS);
	FetchData(&analysis_type,ANALYSISTYPE);
	
	/*!Generate internal degree of freedom numbers: */
	SpcNodesx( &yg, nodes,constraints,analysis_type); 

	/*write output datasets: */
	WriteData(NODES,nodes);
	WriteData(YG,yg);

	/*Free ressources: */
	delete nodes;
	delete constraints;
	VecFree(&yg);

	/*end module: */
	MODULEEND();
}

void SpcNodesUsage(void)
{
	_printf_("\n");
	_printf_("   usage: [m.node,m.yg]=%s(m.nodes,m.constraints);\n",__FUNCT__);
	_printf_("\n");
}
